REV Libraries
==============

These are not installed on the Robot by default. For installation instructions,
see :ref:`robotpy-rev install docs <install_rev>`.

.. warning:: REV does not support all platforms, only the following are available:

             * Windows x64
             * Linux
             * RoboRIO

This documentation documents the various classes and methods that are
available to Python code, but don't discuss in detail how to actually
set up, configure, and tune your REV hardware. For that kind of information,
refer to the `REV software site <https://www.revrobotics.com/sparkmax-software/#api-info>`_.

.. toctree::
    
    rev
